@@ -23,11 +23,11 @@
 #define R2_DATDIR "/usr/share"
 #endif
 
-#define R2_VERSION "0.9.9"
+#define R2_VERSION "0.10.1"
 #define HAVE_LIB_MAGIC 1
 #define USE_LIB_MAGIC 0
 #ifndef HAVE_LIB_SSL
-#define HAVE_LIB_SSL 0
+#define HAVE_LIB_SSL 1
 #endif
 #ifndef HAVE_LIB_EWF
 #define HAVE_LIB_EWF @HAVE_LIB_EWF@
@@ -37,6 +37,6 @@
 
 #define WITH_GPL 1
 
-#define R2_WWWROOT "/usr/share/radare2/0.9.9/www"
+#define R2_WWWROOT R2_DATDIR "/radare2/" R2_VERSION "/www"
 
 #endif
